"""ftp client/server for asyncio"""
# flake8: noqa

import importlib.metadata

from .client import *
from .common import *
from .errors import *
from .pathio import *
from .server import *

__version__ = importlib.metadata.version(__package__)
version = tuple(map(int, __version__.split(".")))

__all__ = (
    client.__all__ + server.__all__ + errors.__all__ + common.__all__ + pathio.__all__ + ("version", "__version__")
)



import pytest

import aioftp


@pytest.mark.asyncio
async def test_permission_denied(
    pair_factory,
    Server,
    expect_codes_in_exception,
):
    s = Server(
        [
            aioftp.User(permissions=[aioftp.Permission(writable=False)]),
        ],
    )
    async with pair_factory(None, s) as pair:
        with expect_codes_in_exception("550"):
            await pair.client.make_directory("foo")


@pytest.mark.asyncio
async def test_permission_overriden(pair_factory, Server):
    s = Server(
        [
            aioftp.User(
                permissions=[
                    aioftp.Permission("/", writable=False),
                    aioftp.Permission("/foo"),
                ],
            ),
        ],
    )
    async with pair_factory(None, s) as pair:
        await pair.client.make_directory("foo")
        await pair.client.remove_directory("foo")



import pytest
from siosocks.exceptions import SocksException


@pytest.mark.asyncio
async def test_socks_success(pair_factory, Client, socks):
    client = Client(
        socks_host=socks.host,
        socks_port=socks.port,
        socks_version=5,
        username="foo",
        password="bar",
    )
    async with pair_factory(client):
        pass


@pytest.mark.asyncio
async def test_socks_fail(pair_factory, Client, socks):
    client = Client(
        socks_host=socks.host,
        socks_port=socks.port,
        socks_version=5,
        username="bar",
        password="bar",
    )
    with pytest.raises(SocksException):
        async with pair_factory(client):
            pass
